pub fn read_file(path: &Path) -> Result<(Frontmatter, String), ParseError>Expand description
Read a file from disk and parse it into typed Frontmatter plus the
verbatim body string.
pub fn read_file(path: &Path) -> Result<(Frontmatter, String), ParseError>Read a file from disk and parse it into typed Frontmatter plus the
verbatim body string.