Section

Struct Section 

pub struct Section {
    pub heading: String,
    pub level: u8,
    pub line: u32,
    pub body: String,
}
A ##/### section of a markdown body: the heading text plus the byte slice of the body it spans (heading line through the line before the next heading of equal-or-shallower depth).

Fields

heading: String

The heading text (without the leading #s).

level: u8

Heading depth (number of leading #s).

line: u32

The 1-based line where the heading appears.

body: String

The section body, from the heading line to the next sibling-or-shallower heading (exclusive), as a slice of the original body.